<?php

declare(strict_types=1);

namespace Drupal\persistent_visitor_parameters_user_registration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Configure Persistent visitor parameters user registration settings.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'persistent_visitor_parameters_user_registration_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['persistent_visitor_parameters_user_registration.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['enable_utm_user_logging'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable UTM User Logging'),
      '#default_value' => $this->config('persistent_visitor_parameters_user_registration.settings')->get('enable_utm_user_logging'),
      '#description' => $this->t('Check this to enable logging of UTM parameters for new user registrations. ONLY the following parameters are supported: <ul><li>utm_source</li><li>utm_medium</li><li>utm_campaign</li><li>utm_term</li><li>utm_content</li><li>HTTP_REFERER</li></ul><br>Note, that you have to specify the following parameters <a href=":url" target="_blank">here</a> first:<br><strong>Get Parameters:</strong> "utm_source|utm_medium|utm_campaign|utm_term|utm_content"<br><strong>Server Parameters:</strong> "HTTP_REFERER"', [':url' => Url::fromRoute('persistent_visitor_parameters.settings')->toString()]),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('persistent_visitor_parameters_user_registration.settings')
      ->set('enable_utm_user_logging', $form_state->getValue('enable_utm_user_logging'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
